@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -115,6 +115,10 @@ sub import {
 
   return if $class->install_type('system');
 
+  # Sanity check in order to ensure that dist_dir can be found.
+  # This will throw an exception otherwise.  
+  $class->dist_dir;
+
   # get a reference to %Alien::MyLibrary::AlienLoaded
   # which contains names of already loaded libraries
   # this logic may be replaced by investigating the DynaLoader arrays
@@ -179,6 +183,9 @@ sub dist_dir {
       ? File::ShareDir::dist_dir($dist) 
       : $class->config('working_directory');
 
+  croak "Failed to find share dir for dist '$dist'"
+    unless -d $dist_dir;
+
   return $dist_dir;
 }
 
